==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkGenericCell.java <==
// java wrapper for vtkGenericCell object
//

package vtk;
import vtk.*;

public class vtkGenericCell extends vtkCell
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetPoints_2(vtkPoints id0);
  public void SetPoints(vtkPoints id0)
    { SetPoints_2(id0); }

  private native void SetPointIds_3(vtkIdList id0);
  public void SetPointIds(vtkIdList id0)
    { SetPointIds_3(id0); }

  private native void ShallowCopy_4(vtkCell id0);
  public void ShallowCopy(vtkCell id0)
    { ShallowCopy_4(id0); }

  private native void DeepCopy_5(vtkCell id0);
  public void DeepCopy(vtkCell id0)
    { DeepCopy_5(id0); }

  private native int GetCellType_6();
  public int GetCellType()
    { return GetCellType_6(); }

  private native int GetCellDimension_7();
  public int GetCellDimension()
    { return GetCellDimension_7(); }

  private native int IsLinear_8();
  public int IsLinear()
    { return IsLinear_8(); }

  private native int RequiresInitialization_9();
  public int RequiresInitialization()
    { return RequiresInitialization_9(); }

  private native void Initialize_10();
  public void Initialize()
    { Initialize_10(); }

  private native int RequiresExplicitFaceRepresentation_11();
  public int RequiresExplicitFaceRepresentation()
    { return RequiresExplicitFaceRepresentation_11(); }

  private native int GetNumberOfEdges_12();
  public int GetNumberOfEdges()
    { return GetNumberOfEdges_12(); }

  private native int GetNumberOfFaces_13();
  public int GetNumberOfFaces()
    { return GetNumberOfFaces_13(); }

  private native long GetEdge_14(int id0);
  public vtkCell GetEdge(int id0) {
    long temp = GetEdge_14(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetFace_15(int id0);
  public vtkCell GetFace(int id0) {
    long temp = GetFace_15(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int CellBoundary_16(int id0,double id1[],vtkIdList id2);
  public int CellBoundary(int id0,double id1[],vtkIdList id2)
    { return CellBoundary_16(id0,id1,id2); }

  private native void Contour_17(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10);
  public void Contour(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10)
    { Contour_17(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9,id10); }

  private native void Clip_18(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9);
  public void Clip(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9)
    { Clip_18(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9); }

  private native int Triangulate_19(int id0,vtkIdList id1,vtkPoints id2);
  public int Triangulate(int id0,vtkIdList id1,vtkPoints id2)
    { return Triangulate_19(id0,id1,id2); }

  private native int GetParametricCenter_20(double id0[]);
  public int GetParametricCenter(double id0[])
    { return GetParametricCenter_20(id0); }

  private native int IsPrimaryCell_21();
  public int IsPrimaryCell()
    { return IsPrimaryCell_21(); }

  private native void SetCellType_22(int id0);
  public void SetCellType(int id0)
    { SetCellType_22(id0); }

  private native void SetCellTypeToEmptyCell_23();
  public void SetCellTypeToEmptyCell()
    { SetCellTypeToEmptyCell_23(); }

  private native void SetCellTypeToVertex_24();
  public void SetCellTypeToVertex()
    { SetCellTypeToVertex_24(); }

  private native void SetCellTypeToPolyVertex_25();
  public void SetCellTypeToPolyVertex()
    { SetCellTypeToPolyVertex_25(); }

  private native void SetCellTypeToLine_26();
  public void SetCellTypeToLine()
    { SetCellTypeToLine_26(); }

  private native void SetCellTypeToPolyLine_27();
  public void SetCellTypeToPolyLine()
    { SetCellTypeToPolyLine_27(); }

  private native void SetCellTypeToTriangle_28();
  public void SetCellTypeToTriangle()
    { SetCellTypeToTriangle_28(); }

  private native void SetCellTypeToTriangleStrip_29();
  public void SetCellTypeToTriangleStrip()
    { SetCellTypeToTriangleStrip_29(); }

  private native void SetCellTypeToPolygon_30();
  public void SetCellTypeToPolygon()
    { SetCellTypeToPolygon_30(); }

  private native void SetCellTypeToPixel_31();
  public void SetCellTypeToPixel()
    { SetCellTypeToPixel_31(); }

  private native void SetCellTypeToQuad_32();
  public void SetCellTypeToQuad()
    { SetCellTypeToQuad_32(); }

  private native void SetCellTypeToTetra_33();
  public void SetCellTypeToTetra()
    { SetCellTypeToTetra_33(); }

  private native void SetCellTypeToVoxel_34();
  public void SetCellTypeToVoxel()
    { SetCellTypeToVoxel_34(); }

  private native void SetCellTypeToHexahedron_35();
  public void SetCellTypeToHexahedron()
    { SetCellTypeToHexahedron_35(); }

  private native void SetCellTypeToWedge_36();
  public void SetCellTypeToWedge()
    { SetCellTypeToWedge_36(); }

  private native void SetCellTypeToPyramid_37();
  public void SetCellTypeToPyramid()
    { SetCellTypeToPyramid_37(); }

  private native void SetCellTypeToPentagonalPrism_38();
  public void SetCellTypeToPentagonalPrism()
    { SetCellTypeToPentagonalPrism_38(); }

  private native void SetCellTypeToHexagonalPrism_39();
  public void SetCellTypeToHexagonalPrism()
    { SetCellTypeToHexagonalPrism_39(); }

  private native void SetCellTypeToPolyhedron_40();
  public void SetCellTypeToPolyhedron()
    { SetCellTypeToPolyhedron_40(); }

  private native void SetCellTypeToConvexPointSet_41();
  public void SetCellTypeToConvexPointSet()
    { SetCellTypeToConvexPointSet_41(); }

  private native void SetCellTypeToQuadraticEdge_42();
  public void SetCellTypeToQuadraticEdge()
    { SetCellTypeToQuadraticEdge_42(); }

  private native void SetCellTypeToCubicLine_43();
  public void SetCellTypeToCubicLine()
    { SetCellTypeToCubicLine_43(); }

  private native void SetCellTypeToQuadraticTriangle_44();
  public void SetCellTypeToQuadraticTriangle()
    { SetCellTypeToQuadraticTriangle_44(); }

  private native void SetCellTypeToBiQuadraticTriangle_45();
  public void SetCellTypeToBiQuadraticTriangle()
    { SetCellTypeToBiQuadraticTriangle_45(); }

  private native void SetCellTypeToQuadraticQuad_46();
  public void SetCellTypeToQuadraticQuad()
    { SetCellTypeToQuadraticQuad_46(); }

  private native void SetCellTypeToQuadraticPolygon_47();
  public void SetCellTypeToQuadraticPolygon()
    { SetCellTypeToQuadraticPolygon_47(); }

  private native void SetCellTypeToQuadraticTetra_48();
  public void SetCellTypeToQuadraticTetra()
    { SetCellTypeToQuadraticTetra_48(); }

  private native void SetCellTypeToQuadraticHexahedron_49();
  public void SetCellTypeToQuadraticHexahedron()
    { SetCellTypeToQuadraticHexahedron_49(); }

  private native void SetCellTypeToQuadraticWedge_50();
  public void SetCellTypeToQuadraticWedge()
    { SetCellTypeToQuadraticWedge_50(); }

  private native void SetCellTypeToQuadraticPyramid_51();
  public void SetCellTypeToQuadraticPyramid()
    { SetCellTypeToQuadraticPyramid_51(); }

  private native void SetCellTypeToQuadraticLinearQuad_52();
  public void SetCellTypeToQuadraticLinearQuad()
    { SetCellTypeToQuadraticLinearQuad_52(); }

  private native void SetCellTypeToBiQuadraticQuad_53();
  public void SetCellTypeToBiQuadraticQuad()
    { SetCellTypeToBiQuadraticQuad_53(); }

  private native void SetCellTypeToQuadraticLinearWedge_54();
  public void SetCellTypeToQuadraticLinearWedge()
    { SetCellTypeToQuadraticLinearWedge_54(); }

  private native void SetCellTypeToBiQuadraticQuadraticWedge_55();
  public void SetCellTypeToBiQuadraticQuadraticWedge()
    { SetCellTypeToBiQuadraticQuadraticWedge_55(); }

  private native void SetCellTypeToTriQuadraticHexahedron_56();
  public void SetCellTypeToTriQuadraticHexahedron()
    { SetCellTypeToTriQuadraticHexahedron_56(); }

  private native void SetCellTypeToBiQuadraticQuadraticHexahedron_57();
  public void SetCellTypeToBiQuadraticQuadraticHexahedron()
    { SetCellTypeToBiQuadraticQuadraticHexahedron_57(); }

  private native long InstantiateCell_58(int id0);
  public vtkCell InstantiateCell(int id0) {
    long temp = InstantiateCell_58(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRepresentativeCell_59();
  public vtkCell GetRepresentativeCell() {
    long temp = GetRepresentativeCell_59();

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkGenericCell() { super(); }

  public vtkGenericCell(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-4-armv7h.pkg.tar.xz: vtk/vtkGenericCell.java <==
// java wrapper for vtkGenericCell object
//

package vtk;
import vtk.*;

public class vtkGenericCell extends vtkCell
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetPoints_2(vtkPoints id0);
  public void SetPoints(vtkPoints id0)
    { SetPoints_2(id0); }

  private native void SetPointIds_3(vtkIdList id0);
  public void SetPointIds(vtkIdList id0)
    { SetPointIds_3(id0); }

  private native void ShallowCopy_4(vtkCell id0);
  public void ShallowCopy(vtkCell id0)
    { ShallowCopy_4(id0); }

  private native void DeepCopy_5(vtkCell id0);
  public void DeepCopy(vtkCell id0)
    { DeepCopy_5(id0); }

  private native int GetCellType_6();
  public int GetCellType()
    { return GetCellType_6(); }

  private native int GetCellDimension_7();
  public int GetCellDimension()
    { return GetCellDimension_7(); }

  private native int IsLinear_8();
  public int IsLinear()
    { return IsLinear_8(); }

  private native int RequiresInitialization_9();
  public int RequiresInitialization()
    { return RequiresInitialization_9(); }

  private native void Initialize_10();
  public void Initialize()
    { Initialize_10(); }

  private native int RequiresExplicitFaceRepresentation_11();
  public int RequiresExplicitFaceRepresentation()
    { return RequiresExplicitFaceRepresentation_11(); }

  private native int GetNumberOfEdges_12();
  public int GetNumberOfEdges()
    { return GetNumberOfEdges_12(); }

  private native int GetNumberOfFaces_13();
  public int GetNumberOfFaces()
    { return GetNumberOfFaces_13(); }

  private native long GetEdge_14(int id0);
  public vtkCell GetEdge(int id0) {
    long temp = GetEdge_14(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetFace_15(int id0);
  public vtkCell GetFace(int id0) {
    long temp = GetFace_15(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int CellBoundary_16(int id0,double id1[],vtkIdList id2);
  public int CellBoundary(int id0,double id1[],vtkIdList id2)
    { return CellBoundary_16(id0,id1,id2); }

  private native void Contour_17(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10);
  public void Contour(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10)
    { Contour_17(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9,id10); }

  private native void Clip_18(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9);
  public void Clip(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9)
    { Clip_18(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9); }

  private native int Triangulate_19(int id0,vtkIdList id1,vtkPoints id2);
  public int Triangulate(int id0,vtkIdList id1,vtkPoints id2)
    { return Triangulate_19(id0,id1,id2); }

  private native int GetParametricCenter_20(double id0[]);
  public int GetParametricCenter(double id0[])
    { return GetParametricCenter_20(id0); }

  private native int IsPrimaryCell_21();
  public int IsPrimaryCell()
    { return IsPrimaryCell_21(); }

  private native void SetCellType_22(int id0);
  public void SetCellType(int id0)
    { SetCellType_22(id0); }

  private native void SetCellTypeToEmptyCell_23();
  public void SetCellTypeToEmptyCell()
    { SetCellTypeToEmptyCell_23(); }

  private native void SetCellTypeToVertex_24();
  public void SetCellTypeToVertex()
    { SetCellTypeToVertex_24(); }

  private native void SetCellTypeToPolyVertex_25();
  public void SetCellTypeToPolyVertex()
    { SetCellTypeToPolyVertex_25(); }

  private native void SetCellTypeToLine_26();
  public void SetCellTypeToLine()
    { SetCellTypeToLine_26(); }

  private native void SetCellTypeToPolyLine_27();
  public void SetCellTypeToPolyLine()
    { SetCellTypeToPolyLine_27(); }

  private native void SetCellTypeToTriangle_28();
  public void SetCellTypeToTriangle()
    { SetCellTypeToTriangle_28(); }

  private native void SetCellTypeToTriangleStrip_29();
  public void SetCellTypeToTriangleStrip()
    { SetCellTypeToTriangleStrip_29(); }

  private native void SetCellTypeToPolygon_30();
  public void SetCellTypeToPolygon()
    { SetCellTypeToPolygon_30(); }

  private native void SetCellTypeToPixel_31();
  public void SetCellTypeToPixel()
    { SetCellTypeToPixel_31(); }

  private native void SetCellTypeToQuad_32();
  public void SetCellTypeToQuad()
    { SetCellTypeToQuad_32(); }

  private native void SetCellTypeToTetra_33();
  public void SetCellTypeToTetra()
    { SetCellTypeToTetra_33(); }

  private native void SetCellTypeToVoxel_34();
  public void SetCellTypeToVoxel()
    { SetCellTypeToVoxel_34(); }

  private native void SetCellTypeToHexahedron_35();
  public void SetCellTypeToHexahedron()
    { SetCellTypeToHexahedron_35(); }

  private native void SetCellTypeToWedge_36();
  public void SetCellTypeToWedge()
    { SetCellTypeToWedge_36(); }

  private native void SetCellTypeToPyramid_37();
  public void SetCellTypeToPyramid()
    { SetCellTypeToPyramid_37(); }

  private native void SetCellTypeToPentagonalPrism_38();
  public void SetCellTypeToPentagonalPrism()
    { SetCellTypeToPentagonalPrism_38(); }

  private native void SetCellTypeToHexagonalPrism_39();
  public void SetCellTypeToHexagonalPrism()
    { SetCellTypeToHexagonalPrism_39(); }

  private native void SetCellTypeToPolyhedron_40();
  public void SetCellTypeToPolyhedron()
    { SetCellTypeToPolyhedron_40(); }

  private native void SetCellTypeToConvexPointSet_41();
  public void SetCellTypeToConvexPointSet()
    { SetCellTypeToConvexPointSet_41(); }

  private native void SetCellTypeToQuadraticEdge_42();
  public void SetCellTypeToQuadraticEdge()
    { SetCellTypeToQuadraticEdge_42(); }

  private native void SetCellTypeToCubicLine_43();
  public void SetCellTypeToCubicLine()
    { SetCellTypeToCubicLine_43(); }

  private native void SetCellTypeToQuadraticTriangle_44();
  public void SetCellTypeToQuadraticTriangle()
    { SetCellTypeToQuadraticTriangle_44(); }

  private native void SetCellTypeToBiQuadraticTriangle_45();
  public void SetCellTypeToBiQuadraticTriangle()
    { SetCellTypeToBiQuadraticTriangle_45(); }

  private native void SetCellTypeToQuadraticQuad_46();
  public void SetCellTypeToQuadraticQuad()
    { SetCellTypeToQuadraticQuad_46(); }

  private native void SetCellTypeToQuadraticPolygon_47();
  public void SetCellTypeToQuadraticPolygon()
    { SetCellTypeToQuadraticPolygon_47(); }

  private native void SetCellTypeToQuadraticTetra_48();
  public void SetCellTypeToQuadraticTetra()
    { SetCellTypeToQuadraticTetra_48(); }

  private native void SetCellTypeToQuadraticHexahedron_49();
  public void SetCellTypeToQuadraticHexahedron()
    { SetCellTypeToQuadraticHexahedron_49(); }

  private native void SetCellTypeToQuadraticWedge_50();
  public void SetCellTypeToQuadraticWedge()
    { SetCellTypeToQuadraticWedge_50(); }

  private native void SetCellTypeToQuadraticPyramid_51();
  public void SetCellTypeToQuadraticPyramid()
    { SetCellTypeToQuadraticPyramid_51(); }

  private native void SetCellTypeToQuadraticLinearQuad_52();
  public void SetCellTypeToQuadraticLinearQuad()
    { SetCellTypeToQuadraticLinearQuad_52(); }

  private native void SetCellTypeToBiQuadraticQuad_53();
  public void SetCellTypeToBiQuadraticQuad()
    { SetCellTypeToBiQuadraticQuad_53(); }

  private native void SetCellTypeToQuadraticLinearWedge_54();
  public void SetCellTypeToQuadraticLinearWedge()
    { SetCellTypeToQuadraticLinearWedge_54(); }

  private native void SetCellTypeToBiQuadraticQuadraticWedge_55();
  public void SetCellTypeToBiQuadraticQuadraticWedge()
    { SetCellTypeToBiQuadraticQuadraticWedge_55(); }

  private native void SetCellTypeToTriQuadraticHexahedron_56();
  public void SetCellTypeToTriQuadraticHexahedron()
    { SetCellTypeToTriQuadraticHexahedron_56(); }

  private native void SetCellTypeToBiQuadraticQuadraticHexahedron_57();
  public void SetCellTypeToBiQuadraticQuadraticHexahedron()
    { SetCellTypeToBiQuadraticQuadraticHexahedron_57(); }

  private native long InstantiateCell_58(int id0);
  public vtkCell InstantiateCell(int id0) {
    long temp = InstantiateCell_58(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRepresentativeCell_59();
  public vtkCell GetRepresentativeCell() {
    long temp = GetRepresentativeCell_59();

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkGenericCell() { super(); }

  public vtkGenericCell(long id) { super(id); }
  public native long   VTKInit();

}
